==> qbittorrent_3.3.1.orig.tar.xz: qbittorrent-3.3.1/src/base/http/responsebuilder.h <==
/*
 * Bittorrent Client using Qt and libtorrent.
 * Copyright (C) 2015  Vladimir Golovnev <glassez@yandex.ru>
 *
 * This program is free software; you can redistribute it and/or
 * modify it under the terms of the GNU General Public License
 * as published by the Free Software Foundation; either version 2
 * of the License, or (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program; if not, write to the Free Software
 * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301, USA.
 *
 * In addition, as a special exception, the copyright holders give permission to
 * link this program with the OpenSSL project's "OpenSSL" library (or with
 * modified versions of it that use the same license as the "OpenSSL" library),
 * and distribute the linked executables. You must obey the GNU General Public
 * License in all respects for all of the code used other than "OpenSSL".  If you
 * modify file(s), you may extend this exception to your version of the file(s),
 * but you are not obligated to do so. If you do not wish to do so, delete this
 * exception statement from your version.
 */

#ifndef HTTP_RESPONSEBUILDER_H
#define HTTP_RESPONSEBUILDER_H

#include <QObject>
#include "types.h"

namespace Http
{
    class ResponseBuilder : public QObject
    {
    public:
        explicit ResponseBuilder(QObject *parent = 0);

    protected:
        void status(uint code = 200, const QString &text = QLatin1String("OK"));
        void header(const QString &name, const QString &value);
        void print(const QString &text, const QString &type = CONTENT_TYPE_HTML);
        void print(const QByteArray &data, const QString &type = CONTENT_TYPE_HTML);
        void clear();

        Response response() const;

    private:
        void print_impl(const QByteArray &data, const QString &type);

        Response m_response;
    };
}

#endif // HTTP_RESPONSEBUILDER_H

==> qbittorrent_4.0.3.orig.tar.xz: qbittorrent-4.0.3/src/base/http/responsebuilder.h <==
/*
 * Bittorrent Client using Qt and libtorrent.
 * Copyright (C) 2015  Vladimir Golovnev <glassez@yandex.ru>
 *
 * This program is free software; you can redistribute it and/or
 * modify it under the terms of the GNU General Public License
 * as published by the Free Software Foundation; either version 2
 * of the License, or (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program; if not, write to the Free Software
 * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301, USA.
 *
 * In addition, as a special exception, the copyright holders give permission to
 * link this program with the OpenSSL project's "OpenSSL" library (or with
 * modified versions of it that use the same license as the "OpenSSL" library),
 * and distribute the linked executables. You must obey the GNU General Public
 * License in all respects for all of the code used other than "OpenSSL".  If you
 * modify file(s), you may extend this exception to your version of the file(s),
 * but you are not obligated to do so. If you do not wish to do so, delete this
 * exception statement from your version.
 */

#ifndef HTTP_RESPONSEBUILDER_H
#define HTTP_RESPONSEBUILDER_H

#include <QObject>
#include "types.h"

namespace Http
{
    class ResponseBuilder : public QObject
    {
    public:
        explicit ResponseBuilder(QObject *parent = nullptr);

    protected:
        void status(uint code = 200, const QString &text = QLatin1String("OK"));
        void header(const QString &name, const QString &value);
        void print(const QString &text, const QString &type = CONTENT_TYPE_HTML);
        void print(const QByteArray &data, const QString &type = CONTENT_TYPE_HTML);
        void clear();

        Response response() const;

    private:
        void print_impl(const QByteArray &data, const QString &type);

        Response m_response;
    };
}

#endif // HTTP_RESPONSEBUILDER_H
